@@ -1,6 +1,6 @@
 ## no critic (RequireUseStrict)
 package Dist::Zilla::Plugin::Test::LocalBrew;
-$Dist::Zilla::Plugin::Test::LocalBrew::VERSION = '0.07';
+$Dist::Zilla::Plugin::Test::LocalBrew::VERSION = '0.08';
 use File::Spec;
 use File::Temp qw(tempdir);
 
@@ -87,7 +87,23 @@ chomp $cpanm_path;
 my $perlbrew_bin = File::Spec->catdir($ENV{'PERLBREW_ROOT'}, 'perls',
     $brew, 'bin');
 
+my $perlbrew_path = $ENV{'PATH'};
+if(my $local_lib_root = $ENV{'PERL_LOCAL_LIB_ROOT'}) {
+    my @path = File::Spec->path;
+
+    while(@path && $path[0] =~ /^$local_lib_root/) {
+        shift @path;
+    }
+
+    if($^O eq 'MSWin32') {
+        $perlbrew_path = join(';', @path);
+    } else {
+        $perlbrew_path = join(':', @path);
+    }
+}
+
 my ( $env, $status ) = do {
+    local $ENV{'PATH'} = $perlbrew_path;
     local $ENV{'SHELL'} = '/bin/bash'; # fool perlbrew
     ( scalar(qx(perlbrew env $brew)), $? )
 };
@@ -112,7 +128,10 @@ foreach my $line (@lines) {
     }
 }
 
-my $pristine_path = qx(perlbrew display-pristine-path);
+my $pristine_path = do {
+    local $ENV{'PATH'} = $perlbrew_path;
+    qx(perlbrew display-pristine-path);
+};
 chomp $pristine_path;
 $ENV{'PATH'} = join(':', $ENV{'PERLBREW_PATH'}, $pristine_path);
 
@@ -129,9 +148,9 @@ if(!defined $pid) {
     waitpid $pid, 0;
     ok !$?, "cpanm should successfully install your dist with no issues" or copy_log_file($tmphome->dirname);
 } else {
-    close STDIN;
-    close STDOUT;
-    close STDERR;
+    open STDIN, '<', File::Spec->devnull;
+    open STDOUT, '>', File::Spec->devnull;
+    open STDERR, '>', File::Spec->devnull;
 
     my @path = File::Spec->splitdir($FindBin::Bin);
 
@@ -146,7 +165,7 @@ if(!defined $pid) {
     # override where cpanm puts its log file
     $ENV{'HOME'} = $tmphome->dirname;
 
-    {{
+{{
         unless($should_test_deps) {
             return <<'END_PERL';
     system 'perl', $cpanm_path, '--notest', '--installdeps', '-L', $tmpdir->dirname, '.';
@@ -156,8 +175,10 @@ if(!defined $pid) {
 END_PERL
         }
         return '';
-    }}
+}}
 
+    # We use system here instead of exec so that $tmpdir gets cleaned up
+    # after cpanm finishes
     system 'perl', $cpanm_path, '-L', $tmpdir->dirname, '.';
     exit($? >> 8);
 }
@@ -206,7 +227,7 @@ Dist::Zilla::Plugin::Test::LocalBrew - Verify that your distribution tests well
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
